#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rss_parser_1 = __importDefault(require("rss-parser"));
const ora_1 = __importDefault(require("ora"));
const inquirer_1 = __importDefault(require("inquirer"));
const opn_1 = __importDefault(require("opn"));
const feedToChoices = (feed) => {
    return new Promise((resolve, reject) => {
        if (feed.items) {
            const choices = feed.items.map(({ title, link }, index) => {
                return {
                    name: title,
                    value: `${index + 1}`,
                    link,
                };
            });
            resolve(choices);
        }
        else {
            reject('No feed items available');
        }
    });
};
const main = () => __awaiter(this, void 0, void 0, function* () {
    const spinner = ora_1.default({
        color: 'white',
        text: 'Loading rss feed',
    }).start();
    const parser = new rss_parser_1.default();
    const feed = yield parser.parseURL('https://www.nu.nl/rss/Algemeen');
    spinner.stop();
    const choices = yield feedToChoices(feed);
    const { selected } = yield inquirer_1.default.prompt([
        {
            type: 'rawlist',
            name: 'selected',
            message: 'Select headline',
            choices,
            pageSize: 100,
        },
    ]);
    const link = choices[selected - 1].link;
    process.stdout.write(`Opening in browser: ${link}\n`);
    opn_1.default(link);
    process.exit();
});
main().catch(console.error);
